@@ -8,6 +8,8 @@ pub struct Config {
     pub server: ServerConfig,
     /// Paste configuration.
     pub paste: PasteConfig,
+    /// Style configuration.
+    pub style: Option<StyleConfig>,
 }
 
 /// Server configuration.
@@ -28,6 +30,13 @@ pub struct PasteConfig {
     pub expire: Option<String>,
 }
 
+/// Style configuration.
+#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+pub struct StyleConfig {
+    /// Whether if the output will be prettified.
+    pub prettify: bool,
+}
+
 impl Config {
     /// Override the configuration file with arguments.
     pub fn update_from_args(&mut self, args: &Args) {
