@@ -14,25 +14,38 @@ pub mod upload;
 
 use crate::args::Args;
 use crate::config::Config;
-use crate::error::Result;
+use crate::error::{Error, Result};
 use crate::upload::Uploader;
 use colored::Colorize;
 use std::fs;
 use std::io::{self, Read};
 
+/// Default name of the configuration file.
+const CONFIG_FILE: &str = "config.toml";
+
 /// Runs `rpaste`.
 pub fn run(args: Args) -> Result<()> {
-    let mut config = if let Some(ref config_path) = args.config {
-        toml::from_str(&fs::read_to_string(&config_path)?)?
-    } else if let Some(path) = dirs_next::home_dir()
-        .map(|p| p.join(".rustypaste").join("config.toml"))
-        .and_then(|p| p.exists().then(|| p))
-    {
-        toml::from_str(&fs::read_to_string(&path)?)?
+    let mut config = Config::default();
+    if let Some(ref config_path) = args.config {
+        config = toml::from_str(&fs::read_to_string(&config_path)?)?
     } else {
-        Config::default()
-    };
+        for path in vec![
+            dirs_next::home_dir().map(|p| p.join(".rustypaste").join(CONFIG_FILE)),
+            dirs_next::config_dir().map(|p| p.join("rustypaste").join(CONFIG_FILE)),
+        ]
+        .iter()
+        .filter_map(|v| v.as_ref())
+        {
+            if path.exists() {
+                config = toml::from_str(&fs::read_to_string(&path)?)?;
+                break;
+            }
+        }
+    }
     config.update_from_args(&args);
+    if config.server.address.is_empty() {
+        return Err(Error::NoServerAddressError);
+    }
 
     let mut results = Vec::new();
     let uploader = Uploader::new(&config);
@@ -52,14 +65,18 @@ pub fn run(args: Args) -> Result<()> {
             results.push(uploader.upload_file(file))
         }
     }
-
-    let format_padding = args
-        .prettify
+    let prettify = args.prettify
+        || config
+            .style
+            .as_ref()
+            .map(|style| style.prettify)
+            .unwrap_or(false);
+    let format_padding = prettify
         .then(|| results.iter().map(|v| v.0.len()).max())
         .flatten()
         .unwrap_or(1);
     for (data, result) in results.iter().map(|v| (v.0, v.1.as_ref())) {
-        let data = if args.prettify {
+        let data = if prettify {
             format!(
                 "{:p$} {} ",
                 data,
